// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

var DotNetSupportLib = {
	$DOTNET: {
		conv_string: function (mono_obj) {
			return MONO.string_decoder.copy (mono_obj);
		}
	},
	mono_wasm_invoke_js_blazor: function(exceptionMessage, callInfo, arg0, arg1, arg2)	{
		var mono_string = globalThis._mono_string_cached
			|| (globalThis._mono_string_cached = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']));

		try {
			var blazorExports = globalThis.Blazor;
			if (!blazorExports) {
				throw new Error('The blazor.webassembly.js library is not loaded.');
			}

			return blazorExports._internal.invokeJSFromDotNet(callInfo, arg0, arg1, arg2);
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	},

	// This is for back-compat only and will eventually be removed
	mono_wasm_invoke_js_marshalled: function(exceptionMessage, asyncHandleLongPtr, functionName, argsJson, treatResultAsVoid) {

		var mono_string = globalThis._mono_string_cached
			|| (globalThis._mono_string_cached = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']));

		try {
			// Passing a .NET long into JS via Emscripten is tricky. The method here is to pass
			// as pointer to the long, then combine two reads from the HEAPU32 array.
			// Even though JS numbers can't represent the full range of a .NET long, it's OK
			// because we'll never exceed Number.MAX_SAFE_INTEGER (2^53 - 1) in this case.
			//var u32Index = $1 >> 2;
			var u32Index = asyncHandleLongPtr >> 2;
			var asyncHandleJsNumber = Module.HEAPU32[u32Index + 1]*4294967296 + Module.HEAPU32[u32Index];

			// var funcNameJsString = UTF8ToString (functionName);
			// var argsJsonJsString = argsJson && UTF8ToString (argsJson);
			var funcNameJsString = DOTNET.conv_string(functionName);
			var argsJsonJsString = argsJson && DOTNET.conv_string (argsJson);

			var dotNetExports = globaThis.DotNet;
			if (!dotNetExports) {
				throw new Error('The Microsoft.JSInterop.js library is not loaded.');
			}

			if (asyncHandleJsNumber) {
				dotNetExports.jsCallDispatcher.beginInvokeJSFromDotNet(asyncHandleJsNumber, funcNameJsString, argsJsonJsString, treatResultAsVoid);
				return 0;
			} else {
				var resultJson = dotNetExports.jsCallDispatcher.invokeJSFromDotNet(funcNameJsString, argsJsonJsString, treatResultAsVoid);
				return resultJson === null ? 0 : mono_string(resultJson);
			}
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	},

	// This is for back-compat only and will eventually be removed
	mono_wasm_invoke_js_unmarshalled: function(exceptionMessage, funcName, arg0, arg1, arg2)	{
		try {
			// Get the function you're trying to invoke
			var funcNameJsString = DOTNET.conv_string(funcName);
			var dotNetExports = globalThis.DotNet;
			if (!dotNetExports) {
				throw new Error('The Microsoft.JSInterop.js library is not loaded.');
			}
			var funcInstance = dotNetExports.jsCallDispatcher.findJSFunction(funcNameJsString);

			return funcInstance.call(null, arg0, arg1, arg2);
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var mono_string = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']); // TODO: Cache
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	}


};

autoAddDeps(DotNetSupportLib, '$DOTNET')
mergeInto(LibraryManager.library, DotNetSupportLib)


// SIG // Begin signature block
// SIG // MIIoiwYJKoZIhvcNAQcCoIIofDCCKHgCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // DQxM5aUosMIFmI353dLRcro0jWTAvinWkY5FLkoNZqCg
// SIG // gg3wMIIGbjCCBFagAwIBAgITMwAAAwVNYg1ohQeqMwAA
// SIG // AAADBTANBgkqhkiG9w0BAQwFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDExMB4XDTIyMDgwNDIwMjM1N1oX
// SIG // DTIzMDgwMzIwMjM1N1owYzELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjENMAsGA1UEAxMELk5FVDCCAaIwDQYJKoZIhvcNAQEB
// SIG // BQADggGPADCCAYoCggGBALgT1J98uPoa1weiQsnOFH3y
// SIG // L9VcrQ5JLGIZT50ZFJp4cOpQ+gHtRxxVE89hPiTPzLAR
// SIG // VHaubXNodZsBmWk4PbWNkPwm0aKis02uN71Farp9Ouc5
// SIG // 0Pzn1DT+R3+e3ahXLhtC5mlTaCZiJ4AU3blyaqQLKLeJ
// SIG // a3pqyHBnJiXySNBrhLBkleguDLiqBLaziCWbQLAIlLUl
// SIG // ypI/cutECrDKU4/f7PHM+1gUQdK+WZnH/+t82oAY0VXG
// SIG // 3pUMZzv3UysNO4CS1aFAjQG5cjdJuS812n658mOSIPwF
// SIG // 5zmfaIH14qh/XPyfi0a6WdZaZIRth3dnP9VcGN1sDSuc
// SIG // RV/no9+aSPqWyt19ipN4jiuJILUHhm+3eekt2KGaKWys
// SIG // 2whswE1RkBoAq7GmvFIrXvcEB0mqM/09bIfgvkjN50z/
// SIG // 5XmMlyrqtmD0Fe+V1DTbfOyhdBZpt4G2cbqK3eoFUoJI
// SIG // ytn3N06zIBT0kd8BVWDWKOTi0VHsXx8cvHDKDLOL5iK2
// SIG // REcibwIDAQABo4IBfjCCAXowHwYDVR0lBBgwFgYKKwYB
// SIG // BAGCN0wIAQYIKwYBBQUHAwMwHQYDVR0OBBYEFMPGGeTy
// SIG // z3Y+F0AQcJOKcmziq1YbMFAGA1UdEQRJMEekRTBDMSkw
// SIG // JwYDVQQLEyBNaWNyb3NvZnQgT3BlcmF0aW9ucyBQdWVy
// SIG // dG8gUmljbzEWMBQGA1UEBRMNNDY0MjIzKzQ3MjIzNzAf
// SIG // BgNVHSMEGDAWgBRIbmTlUAXTgqoXNzcitW2oynUClTBU
// SIG // BgNVHR8ETTBLMEmgR6BFhkNodHRwOi8vd3d3Lm1pY3Jv
// SIG // c29mdC5jb20vcGtpb3BzL2NybC9NaWNDb2RTaWdQQ0Ey
// SIG // MDExXzIwMTEtMDctMDguY3JsMGEGCCsGAQUFBwEBBFUw
// SIG // UzBRBggrBgEFBQcwAoZFaHR0cDovL3d3dy5taWNyb3Nv
// SIG // ZnQuY29tL3BraW9wcy9jZXJ0cy9NaWNDb2RTaWdQQ0Ey
// SIG // MDExXzIwMTEtMDctMDguY3J0MAwGA1UdEwEB/wQCMAAw
// SIG // DQYJKoZIhvcNAQEMBQADggIBAGhKSnmsyGvycL6Dw4uq
// SIG // 3wDtwdM/hSbG6b5NqxUtIoE9TMT4Uqj+NWtYfrB09uq8
// SIG // OzxkLHnaEec19x5EyVxy+DBpbmzNU3/469qF4kyp0FNj
// SIG // CJlmFgFoxLNFzisxKeTXw1pFppM5AxHG+/VqIdQlOCbc
// SIG // 2nTSJLqxag4G3J+fsEE6uywxw6NxfieRBzAJd2HGPLUV
// SIG // pt87GLklNjsyxDUJYkxFtgkj1khGqwIG6ZNkbIXPsxR8
// SIG // S9oiKqAP71cZEwN6+TnnPIotqXeBsC+urL/NB8NWxBEe
// SIG // npVFFF4zNXd3sbmb4H/668DKQaIP5Qm0Ige2nmxgXAPq
// SIG // 9CPYZawXOvxOhOFgiU3AtLFAK/Oc+sgkXCeLX2A6RKq8
// SIG // SqgwHwtjWXaviyEToDFwSMdel+y+9wSZokXBwr+7TjGL
// SIG // uRinndUGjiVtJU/rsz/y9xC5TiOn6BAjwXB0EktoM0dP
// SIG // cTu3d9AC0q2gylEwTPAdfSbpABG+IPHEgtOoDxSBxUGc
// SIG // hdEElyklcwz6C8oGSXR6CVGHV7QW+cH03C9DH7nBBhAh
// SIG // UIojqCYwKb9b8Gam25brrUFwf8to5dXLZ14HYeRA9c6A
// SIG // H2CBwiE4ABPpOq/iypGWil8Vyg3Uf6LmgAEMMxZYLtNg
// SIG // 5GbM3tcTW2M3C0EZFIpiuT43hvm8uNHpXAZP3PJ3yCc5
// SIG // yR09MIIHejCCBWKgAwIBAgIKYQ6Q0gAAAAAAAzANBgkq
// SIG // hkiG9w0BAQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNV
// SIG // BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
// SIG // HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEy
// SIG // MDAGA1UEAxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNh
// SIG // dGUgQXV0aG9yaXR5IDIwMTEwHhcNMTEwNzA4MjA1OTA5
// SIG // WhcNMjYwNzA4MjEwOTA5WjB+MQswCQYDVQQGEwJVUzET
// SIG // MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
// SIG // bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
// SIG // aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWdu
// SIG // aW5nIFBDQSAyMDExMIICIjANBgkqhkiG9w0BAQEFAAOC
// SIG // Ag8AMIICCgKCAgEAq/D6chAcLq3YbqqCEE00uvK2WCGf
// SIG // Qhsqa+laUKq4BjgaBEm6f8MMHt03a8YS2AvwOMKZBrDI
// SIG // OdUBFDFC04kNeWSHfpRgJGyvnkmc6Whe0t+bU7IKLMOv
// SIG // 2akrrnoJr9eWWcpgGgXpZnboMlImEi/nqwhQz7NEt13Y
// SIG // xC4Ddato88tt8zpcoRb0RrrgOGSsbmQ1eKagYw8t00CT
// SIG // +OPeBw3VXHmlSSnnDb6gE3e+lD3v++MrWhAfTVYoonpy
// SIG // 4BI6t0le2O3tQ5GD2Xuye4Yb2T6xjF3oiU+EGvKhL1nk
// SIG // kDstrjNYxbc+/jLTswM9sbKvkjh+0p2ALPVOVpEhNSXD
// SIG // OW5kf1O6nA+tGSOEy/S6A4aN91/w0FK/jJSHvMAhdCVf
// SIG // GCi2zCcoOCWYOUo2z3yxkq4cI6epZuxhH2rhKEmdX4ji
// SIG // JV3TIUs+UsS1Vz8kA/DRelsv1SPjcF0PUUZ3s/gA4bys
// SIG // AoJf28AVs70b1FVL5zmhD+kjSbwYuER8ReTBw3J64HLn
// SIG // JN+/RpnF78IcV9uDjexNSTCnq47f7Fufr/zdsGbiwZeB
// SIG // e+3W7UvnSSmnEyimp31ngOaKYnhfsi+E11ecXL93KCjx
// SIG // 7W3DKI8sj0A3T8HhhUSJxAlMxdSlQy90lfdu+HggWCwT
// SIG // XWCVmj5PM4TasIgX3p5O9JawvEagbJjS4NaIjAsCAwEA
// SIG // AaOCAe0wggHpMBAGCSsGAQQBgjcVAQQDAgEAMB0GA1Ud
// SIG // DgQWBBRIbmTlUAXTgqoXNzcitW2oynUClTAZBgkrBgEE
// SIG // AYI3FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYw
// SIG // DwYDVR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBRyLToC
// SIG // MZBDuRQFTuHqp8cx0SOJNDBaBgNVHR8EUzBRME+gTaBL
// SIG // hklodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2Ny
// SIG // bC9wcm9kdWN0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFf
// SIG // MDNfMjIuY3JsMF4GCCsGAQUFBwEBBFIwUDBOBggrBgEF
// SIG // BQcwAoZCaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
// SIG // aS9jZXJ0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFfMDNf
// SIG // MjIuY3J0MIGfBgNVHSAEgZcwgZQwgZEGCSsGAQQBgjcu
// SIG // AzCBgzA/BggrBgEFBQcCARYzaHR0cDovL3d3dy5taWNy
// SIG // b3NvZnQuY29tL3BraW9wcy9kb2NzL3ByaW1hcnljcHMu
// SIG // aHRtMEAGCCsGAQUFBwICMDQeMiAdAEwAZQBnAGEAbABf
// SIG // AHAAbwBsAGkAYwB5AF8AcwB0AGEAdABlAG0AZQBuAHQA
// SIG // LiAdMA0GCSqGSIb3DQEBCwUAA4ICAQBn8oalmOBUeRou
// SIG // 09h0ZyKbC5YR4WOSmUKWfdJ5DJDBZV8uLD74w3LRbYP+
// SIG // vj/oCso7v0epo/Np22O/IjWll11lhJB9i0ZQVdgMknzS
// SIG // Gksc8zxCi1LQsP1r4z4HLimb5j0bpdS1HXeUOeLpZMlE
// SIG // PXh6I/MTfaaQdION9MsmAkYqwooQu6SpBQyb7Wj6aC6V
// SIG // oCo/KmtYSWMfCWluWpiW5IP0wI/zRive/DvQvTXvbiWu
// SIG // 5a8n7dDd8w6vmSiXmE0OPQvyCInWH8MyGOLwxS3OW560
// SIG // STkKxgrCxq2u5bLZ2xWIUUVYODJxJxp/sfQn+N4sOiBp
// SIG // mLJZiWhub6e3dMNABQamASooPoI/E01mC8CzTfXhj38c
// SIG // bxV9Rad25UAqZaPDXVJihsMdYzaXht/a8/jyFqGaJ+HN
// SIG // pZfQ7l1jQeNbB5yHPgZ3BtEGsXUfFL5hYbXw3MYbBL7f
// SIG // QccOKO7eZS/sl/ahXJbYANahRr1Z85elCUtIEJmAH9AA
// SIG // KcWxm6U/RXceNcbSoqKfenoi+kiVH6v7RyOA9Z74v2u3
// SIG // S5fi63V4GuzqN5l5GEv/1rMjaHXmr/r8i+sLgOppO6/8
// SIG // MO0ETI7f33VtY5E90Z1WTk+/gFcioXgRMiF670EKsT/7
// SIG // qMykXcGhiJtXcVZOSEXAQsmbdlsKgEhr/Xmfwb1tbWrJ
// SIG // UnMTDXpQzTGCGfMwghnvAgEBMIGVMH4xCzAJBgNVBAYT
// SIG // AlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQH
// SIG // EwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
// SIG // cG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2Rl
// SIG // IFNpZ25pbmcgUENBIDIwMTECEzMAAAMFTWINaIUHqjMA
// SIG // AAAAAwUwDQYJYIZIAWUDBAIBBQCgga4wGQYJKoZIhvcN
// SIG // AQkDMQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEO
// SIG // MAwGCisGAQQBgjcCARUwLwYJKoZIhvcNAQkEMSIEIPei
// SIG // aMpT7aW0G0eaO4V7u+OYsUIWBD2V6EuD1ajffj24MEIG
// SIG // CisGAQQBgjcCAQwxNDAyoBSAEgBNAGkAYwByAG8AcwBv
// SIG // AGYAdKEagBhodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20w
// SIG // DQYJKoZIhvcNAQEBBQAEggGAAOiMMlUcSVcZG2sRtROK
// SIG // yoM/PzvvdfB35yy25cGv+Q66BPzfzEz3jgAyJm/cNvJx
// SIG // tsbEzrxNCH+r58Jl0BaDtzTRb6w39J01/GHFH5hB78+x
// SIG // 5KwkhrOdr6JKG4Y9TQmvM+PPII5yvhh5F2XyDKYarYvt
// SIG // 6IO2B3ZvXNWsXzprWQyFztoO9T9QZilzSlsvsgHdQrem
// SIG // d/xMA98I6ZMxeF4xbynTflus5eG56BlwXC4OVO7hlY3l
// SIG // SsXurppMt5vt/Dc0VKfIrXhBg9ZZQr5tFgUedTVmv3PJ
// SIG // jB7F26+1rxIxBHzlWOq+2Y5LhJucMJPalZyXEr7FoG9v
// SIG // we3k/ENqf+qpejR6uNTHNnfkuQWCJz/2qHLFY1rfmDFd
// SIG // svYVNKARdAtztRCtonnvqqSbvAMe1B0FM0MMRD34kABZ
// SIG // qNM104jKu9jAuaxhlgyXryXE1FWDGKUjl8266C09luRJ
// SIG // hAM1ng9dzXQu2rt4jda3PuxmGfIIcfxRUtchwjReKd8/
// SIG // cpjO1hREoYIW/TCCFvkGCisGAQQBgjcDAwExghbpMIIW
// SIG // 5QYJKoZIhvcNAQcCoIIW1jCCFtICAQMxDzANBglghkgB
// SIG // ZQMEAgEFADCCAVEGCyqGSIb3DQEJEAEEoIIBQASCATww
// SIG // ggE4AgEBBgorBgEEAYRZCgMBMDEwDQYJYIZIAWUDBAIB
// SIG // BQAEIG1Cdg6B8ylQKiD7Cu56Uz3qGpTfoHq1O4aKaUq9
// SIG // UeSrAgZjbP9mtdYYEzIwMjIxMjAyMTkyMjIyLjQzN1ow
// SIG // BIACAfSggdCkgc0wgcoxCzAJBgNVBAYTAlVTMRMwEQYD
// SIG // VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25k
// SIG // MR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24x
// SIG // JTAjBgNVBAsTHE1pY3Jvc29mdCBBbWVyaWNhIE9wZXJh
// SIG // dGlvbnMxJjAkBgNVBAsTHVRoYWxlcyBUU1MgRVNOOjdC
// SIG // RjEtRTNFQS1CODA4MSUwIwYDVQQDExxNaWNyb3NvZnQg
// SIG // VGltZS1TdGFtcCBTZXJ2aWNloIIRVDCCBwwwggT0oAMC
// SIG // AQICEzMAAAHI+bDuZ+3qa0YAAQAAAcgwDQYJKoZIhvcN
// SIG // AQELBQAwfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UE
// SIG // AxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAw
// SIG // HhcNMjIxMTA0MTkwMTM3WhcNMjQwMjAyMTkwMTM3WjCB
// SIG // yjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0
// SIG // b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1p
// SIG // Y3Jvc29mdCBDb3Jwb3JhdGlvbjElMCMGA1UECxMcTWlj
// SIG // cm9zb2Z0IEFtZXJpY2EgT3BlcmF0aW9uczEmMCQGA1UE
// SIG // CxMdVGhhbGVzIFRTUyBFU046N0JGMS1FM0VBLUI4MDgx
// SIG // JTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1lLVN0YW1wIFNl
// SIG // cnZpY2UwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIK
// SIG // AoICAQC5y51+KE+DJFbCeci4kKpzdMK0WTRc6KYVwqNT
// SIG // 1tLpYWeDaX4WsiJ3SY9nspazoTCPbVf5mQaQzrH6jMeW
// SIG // Y22cdJDjymMgV2UpciiHt9KjjUDifS1AiXCGzy4hgihy
// SIG // nvbHAMEcpJnEZoRr/TvTuLI7D5pdlc1xPGA2JEQBJv22
// SIG // GUtkzvmZ8kiAFW9SZ0tlz5c5RjDP/y6XsgTO080fhyfw
// SIG // KfS0mEgV+nad62vwZg2iLIirG54bv6xK3bFeXv+KBzlw
// SIG // c9mdaF+X09oHj5K62sDzMCHNUdOePhF9/EDhHeTgFFs9
// SIG // 0ajBB85/3ll5jEtMd/lrAHSepnE5j7K4ZaF/qGnlEZGi
// SIG // 5z1t5Vm/3wzV6thrnlLVqFmAYNAnJxW0TLzZGWYp9Nhj
// SIG // a42aU8ta2cPuwOWlWSFhAYq5Nae7BAqr1lNIT7RXZwfw
// SIG // lpYFglAwi5ZYzze8s+jchP9L/mNPahk5L2ewmDDALBFS
// SIG // 1i3C2rz88m2+3VXpWgbhZ3b8wCJ+AQk6QcXsBE+oj1e/
// SIG // bz6uKolnmaMsbPzh0/avKh7SXFhLPc9PkSsqhLT7Mmlg
// SIG // 0BzFu/ZReJOTdaP+Zne26XPrPhedKXmDLQ8t6v4RWPPg
// SIG // b3oZxmArZ30b65jKUdbAGd4i/1gVCPrIx1b/iwSmQRuu
// SIG // mIk16ZzFQKYGKlntJzfmu/i62Qnj9QIDAQABo4IBNjCC
// SIG // ATIwHQYDVR0OBBYEFLVcL0mButLAsNOIklPiIrs1S+T1
// SIG // MB8GA1UdIwQYMBaAFJ+nFV0AXmJdg/Tl0mWnG1M1Gely
// SIG // MF8GA1UdHwRYMFYwVKBSoFCGTmh0dHA6Ly93d3cubWlj
// SIG // cm9zb2Z0LmNvbS9wa2lvcHMvY3JsL01pY3Jvc29mdCUy
// SIG // MFRpbWUtU3RhbXAlMjBQQ0ElMjAyMDEwKDEpLmNybDBs
// SIG // BggrBgEFBQcBAQRgMF4wXAYIKwYBBQUHMAKGUGh0dHA6
// SIG // Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMvY2VydHMv
// SIG // TWljcm9zb2Z0JTIwVGltZS1TdGFtcCUyMFBDQSUyMDIw
// SIG // MTAoMSkuY3J0MAwGA1UdEwEB/wQCMAAwEwYDVR0lBAww
// SIG // CgYIKwYBBQUHAwgwDQYJKoZIhvcNAQELBQADggIBAMPW
// SIG // clLIQ8OpKCd+QWJ8hu14lvs2RkJtGPnIEaJPV/19Ma9R
// SIG // vkJbuTd5Kne7FSqib0tbKRw19Br9h/DSWJsSKb1hGNQ1
// SIG // wvjaggWq2n/uuX2CDrWiIHw8H7q8sSaNeRjFRRHxaMoo
// SIG // LlDl3H3oHbV9pJyjYw6a+NjEZRHsCf7jnb2VA88upsQp
// SIG // GNw1Bv6n6aRAfZd4xuyHkRAKRO5gCKYVOCe6LZk8UsS4
// SIG // GnEErnPYecqd4dQn2LilwpZ0KoXUA5U3yBcgfRHQV+Ux
// SIG // wKDlNby/3RXDH+Y/doTYiB7W4Twz1g0Gfnvvo/GYDXpn
// SIG // 5zaz6Fgj72wlmGFEDxpJhpyuUvPtpT/no68RhERFBm22
// SIG // 4AWStX4z8n60J4Y2/QZ3vljiUosynn/TGg6+I8F0HasP
// SIG // kL9T4Hyq3VsGpAtVnXAdHLT/oeEnFs6LYiAYlo4JgsZf
// SIG // bPPRUBPqZnYFNasmZwrpIO/utfumyAL4J/W3RHVpYKQI
// SIG // cm2li7IqN/tSh1FrN685/pXTVeSsBEcqsjttCgcUv6y6
// SIG // faWIkIGM3nWYNagSBQIS/AHeX5EVgAvRoiKxzlxNoZf9
// SIG // PwX6IBvP6PYYZW6bzmARBL24vNJ52hg/IRfFNuXB7AZ0
// SIG // DGohloqjNEGjDj06cv7kKCihUx/dlKqnFzZALQTTeXpz
// SIG // +8KGRjKoxersvB3g+ceqMIIHcTCCBVmgAwIBAgITMwAA
// SIG // ABXF52ueAptJmQAAAAAAFTANBgkqhkiG9w0BAQsFADCB
// SIG // iDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0
// SIG // b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1p
// SIG // Y3Jvc29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWlj
// SIG // cm9zb2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9yaXR5
// SIG // IDIwMTAwHhcNMjEwOTMwMTgyMjI1WhcNMzAwOTMwMTgz
// SIG // MjI1WjB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2Fz
// SIG // aGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UE
// SIG // ChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQD
// SIG // Ex1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDCC
// SIG // AiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIBAOTh
// SIG // pkzntHIhC3miy9ckeb0O1YLT/e6cBwfSqWxOdcjKNVf2
// SIG // AX9sSuDivbk+F2Az/1xPx2b3lVNxWuJ+Slr+uDZnhUYj
// SIG // DLWNE893MsAQGOhgfWpSg0S3po5GawcU88V29YZQ3MFE
// SIG // yHFcUTE3oAo4bo3t1w/YJlN8OWECesSq/XJprx2rrPY2
// SIG // vjUmZNqYO7oaezOtgFt+jBAcnVL+tuhiJdxqD89d9P6O
// SIG // U8/W7IVWTe/dvI2k45GPsjksUZzpcGkNyjYtcI4xyDUo
// SIG // veO0hyTD4MmPfrVUj9z6BVWYbWg7mka97aSueik3rMvr
// SIG // g0XnRm7KMtXAhjBcTyziYrLNueKNiOSWrAFKu75xqRdb
// SIG // Z2De+JKRHh09/SDPc31BmkZ1zcRfNN0Sidb9pSB9fvzZ
// SIG // nkXftnIv231fgLrbqn427DZM9ituqBJR6L8FA6PRc6ZN
// SIG // N3SUHDSCD/AQ8rdHGO2n6Jl8P0zbr17C89XYcz1DTsEz
// SIG // OUyOArxCaC4Q6oRRRuLRvWoYWmEBc8pnol7XKHYC4jMY
// SIG // ctenIPDC+hIK12NvDMk2ZItboKaDIV1fMHSRlJTYuVD5
// SIG // C4lh8zYGNRiER9vcG9H9stQcxWv2XFJRXRLbJbqvUAV6
// SIG // bMURHXLvjflSxIUXk8A8FdsaN8cIFRg/eKtFtvUeh17a
// SIG // j54WcmnGrnu3tz5q4i6tAgMBAAGjggHdMIIB2TASBgkr
// SIG // BgEEAYI3FQEEBQIDAQABMCMGCSsGAQQBgjcVAgQWBBQq
// SIG // p1L+ZMSavoKRPEY1Kc8Q/y8E7jAdBgNVHQ4EFgQUn6cV
// SIG // XQBeYl2D9OXSZacbUzUZ6XIwXAYDVR0gBFUwUzBRBgwr
// SIG // BgEEAYI3TIN9AQEwQTA/BggrBgEFBQcCARYzaHR0cDov
// SIG // L3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9Eb2NzL1Jl
// SIG // cG9zaXRvcnkuaHRtMBMGA1UdJQQMMAoGCCsGAQUFBwMI
// SIG // MBkGCSsGAQQBgjcUAgQMHgoAUwB1AGIAQwBBMAsGA1Ud
// SIG // DwQEAwIBhjAPBgNVHRMBAf8EBTADAQH/MB8GA1UdIwQY
// SIG // MBaAFNX2VsuP6KJcYmjRPZSQW9fOmhjEMFYGA1UdHwRP
// SIG // ME0wS6BJoEeGRWh0dHA6Ly9jcmwubWljcm9zb2Z0LmNv
// SIG // bS9wa2kvY3JsL3Byb2R1Y3RzL01pY1Jvb0NlckF1dF8y
// SIG // MDEwLTA2LTIzLmNybDBaBggrBgEFBQcBAQROMEwwSgYI
// SIG // KwYBBQUHMAKGPmh0dHA6Ly93d3cubWljcm9zb2Z0LmNv
// SIG // bS9wa2kvY2VydHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYt
// SIG // MjMuY3J0MA0GCSqGSIb3DQEBCwUAA4ICAQCdVX38Kq3h
// SIG // LB9nATEkW+Geckv8qW/qXBS2Pk5HZHixBpOXPTEztTnX
// SIG // wnE2P9pkbHzQdTltuw8x5MKP+2zRoZQYIu7pZmc6U03d
// SIG // mLq2HnjYNi6cqYJWAAOwBb6J6Gngugnue99qb74py27Y
// SIG // P0h1AdkY3m2CDPVtI1TkeFN1JFe53Z/zjj3G82jfZfak
// SIG // Vqr3lbYoVSfQJL1AoL8ZthISEV09J+BAljis9/kpicO8
// SIG // F7BUhUKz/AyeixmJ5/ALaoHCgRlCGVJ1ijbCHcNhcy4s
// SIG // a3tuPywJeBTpkbKpW99Jo3QMvOyRgNI95ko+ZjtPu4b6
// SIG // MhrZlvSP9pEB9s7GdP32THJvEKt1MMU0sHrYUP4KWN1A
// SIG // PMdUbZ1jdEgssU5HLcEUBHG/ZPkkvnNtyo4JvbMBV0lU
// SIG // ZNlz138eW0QBjloZkWsNn6Qo3GcZKCS6OEuabvshVGtq
// SIG // RRFHqfG3rsjoiV5PndLQTHa1V1QJsWkBRH58oWFsc/4K
// SIG // u+xBZj1p/cvBQUl+fpO+y/g75LcVv7TOPqUxUYS8vwLB
// SIG // gqJ7Fx0ViY1w/ue10CgaiQuPNtq6TPmb/wrpNPgkNWcr
// SIG // 4A245oyZ1uEi6vAnQj0llOZ0dFtq0Z4+7X6gMTN9vMvp
// SIG // e784cETRkPHIqzqKOghif9lwY1NNje6CbaUFEMFxBmoQ
// SIG // tB1VM1izoXBm8qGCAsswggI0AgEBMIH4oYHQpIHNMIHK
// SIG // MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3Rv
// SIG // bjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWlj
// SIG // cm9zb2Z0IENvcnBvcmF0aW9uMSUwIwYDVQQLExxNaWNy
// SIG // b3NvZnQgQW1lcmljYSBPcGVyYXRpb25zMSYwJAYDVQQL
// SIG // Ex1UaGFsZXMgVFNTIEVTTjo3QkYxLUUzRUEtQjgwODEl
// SIG // MCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUtU3RhbXAgU2Vy
// SIG // dmljZaIjCgEBMAcGBSsOAwIaAxUA384TULvGNTQKUgNd
// SIG // AGK5wBjuy7KggYMwgYCkfjB8MQswCQYDVQQGEwJVUzET
// SIG // MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
// SIG // bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
// SIG // aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFt
// SIG // cCBQQ0EgMjAxMDANBgkqhkiG9w0BAQUFAAIFAOc0fm8w
// SIG // IhgPMjAyMjEyMDIyMTM4NTVaGA8yMDIyMTIwMzIxMzg1
// SIG // NVowdDA6BgorBgEEAYRZCgQBMSwwKjAKAgUA5zR+bwIB
// SIG // ADAHAgEAAgIXFDAHAgEAAgIRrTAKAgUA5zXP7wIBADA2
// SIG // BgorBgEEAYRZCgQCMSgwJjAMBgorBgEEAYRZCgMCoAow
// SIG // CAIBAAIDB6EgoQowCAIBAAIDAYagMA0GCSqGSIb3DQEB
// SIG // BQUAA4GBANoxv8V8eVPuYSN4i9RkqajfM3TMharlI+pf
// SIG // /vGmMlBPHz25dg6BeoOMofbtw6ChyjHitVMf0ABkS4H3
// SIG // 2r/ugK5A8maByJU7IgAGHMNlyJy6PFn53OLwrsvWFw10
// SIG // DkwbsC9r8De6S6loDpIH+vqJgSx7bZQinPW8cC3DoqxR
// SIG // BPVPMYIEDTCCBAkCAQEwgZMwfDELMAkGA1UEBhMCVVMx
// SIG // EzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1Jl
// SIG // ZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3Jh
// SIG // dGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3Rh
// SIG // bXAgUENBIDIwMTACEzMAAAHI+bDuZ+3qa0YAAQAAAcgw
// SIG // DQYJYIZIAWUDBAIBBQCgggFKMBoGCSqGSIb3DQEJAzEN
// SIG // BgsqhkiG9w0BCRABBDAvBgkqhkiG9w0BCQQxIgQgtRJN
// SIG // jIiFQiClxseInCT55tFUGaCZaA1zWog3TXrgoBYwgfoG
// SIG // CyqGSIb3DQEJEAIvMYHqMIHnMIHkMIG9BCBiAJjPzT9t
// SIG // oy/HDqNypK8vQVbhN28DT2fEd+w+G4QDZjCBmDCBgKR+
// SIG // MHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5n
// SIG // dG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVN
// SIG // aWNyb3NvZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMTHU1p
// SIG // Y3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEwAhMzAAAB
// SIG // yPmw7mft6mtGAAEAAAHIMCIEIAGSUhDbrW/dTpFvKQkY
// SIG // LxlHZa8urdt5H2n7zOAwmh+YMA0GCSqGSIb3DQEBCwUA
// SIG // BIICADw3ouVF99o1OoPWHnMaJsQ7nXUkG4Tk+gEm/082
// SIG // wgmq8bLO8lIAvxA8s0ROcWYJL1iH936BqKK+aHqkIMLu
// SIG // /eT+wEv+Z+j0i3SnTk25UC2r58pQ9o7q8/aZzFwGPMmm
// SIG // K9nxvYbSzlmaaurtXccrzb6E/YIDQKWxBIbH9tMcVna2
// SIG // R1Vz7m7dOkCoESgEqIs68aqXgd2//wRVK+zNvXQ1AB6q
// SIG // zO727JBOZ2hRvtDvKIvkKh1oKpK5yNKR6k3W7WsBd+o+
// SIG // No9+4GvPcrVUcUOtQB6Of9JY8q2c+7BJMfvvR4pkI4eB
// SIG // gx8hu+Fi77bWu2tHRMy+Sl3CCh1LVYXfXQmVWahT1r5p
// SIG // Aydl9ywuIKMx89ifbmomnkPdncJvaYyldky7VPiOBfI4
// SIG // kWTe3En6lMo9yJvEhIkcnFsG/YIF0oHUcI55bQu6M2mx
// SIG // 7zWD8bmcDAmS6zZXG6lwEn5Jltdhy9be5YIw+ZslPbci
// SIG // 4exluJeoGgxOlSrKbNlyIyNdift/8mwHbqBW6YF6t+JC
// SIG // OubvXP6r88fz19dcKixZ4AnRDnKwyJ6dB5vpFZmrFfWB
// SIG // k1zc1tbEx/17hhftbnfU7U9ZQm67H71AwPSOr8WJ2y70
// SIG // wy6UfRgutygRA6rSEcuCb5Q/mwVjEKHaPQ/XvCslrxxx
// SIG // tsxL1WINL44Mk5R0Zv0nefZVMpWc
// SIG // End signature block
