// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

var DotNetEntropyLib = {
    $DOTNETENTROPY: {
        // batchedQuotaMax is the max number of bytes as specified by the api spec.
        // If the byteLength of array is greater than 65536, throw a QuotaExceededError and terminate the algorithm.
        // https://www.w3.org/TR/WebCryptoAPI/#Crypto-method-getRandomValues
        batchedQuotaMax: 65536,
        getBatchedRandomValues: function (buffer, bufferLength) {
            // for modern web browsers
            // map the work array to the memory buffer passed with the length
            for (var i = 0; i < bufferLength; i += this.batchedQuotaMax) {
                var view = new Uint8Array(Module.HEAPU8.buffer, buffer + i, Math.min(bufferLength - i, this.batchedQuotaMax));
                crypto.getRandomValues(view)
            }
        }
    },
    dotnet_browser_entropy : function (buffer, bufferLength) {
        // check that we have crypto available
        if (typeof crypto === 'object' && typeof crypto['getRandomValues'] === 'function') {
            DOTNETENTROPY.getBatchedRandomValues(buffer, bufferLength)
            return 0;
        } else {
            // we couldn't find a proper implementation, as Math.random() is not suitable
            // instead of aborting here we will return and let managed code handle the message
            return -1;
        }
    },
};

autoAddDeps(DotNetEntropyLib, '$DOTNETENTROPY')
mergeInto(LibraryManager.library, DotNetEntropyLib)

// SIG // Begin signature block
// SIG // MIIojQYJKoZIhvcNAQcCoIIofjCCKHoCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // He0Yy7K+G59QXMN5sHHtOtGJyoFg0Ie3YpqLi1MNoKeg
// SIG // gg3wMIIGbjCCBFagAwIBAgITMwAAAwVNYg1ohQeqMwAA
// SIG // AAADBTANBgkqhkiG9w0BAQwFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDExMB4XDTIyMDgwNDIwMjM1N1oX
// SIG // DTIzMDgwMzIwMjM1N1owYzELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjENMAsGA1UEAxMELk5FVDCCAaIwDQYJKoZIhvcNAQEB
// SIG // BQADggGPADCCAYoCggGBALgT1J98uPoa1weiQsnOFH3y
// SIG // L9VcrQ5JLGIZT50ZFJp4cOpQ+gHtRxxVE89hPiTPzLAR
// SIG // VHaubXNodZsBmWk4PbWNkPwm0aKis02uN71Farp9Ouc5
// SIG // 0Pzn1DT+R3+e3ahXLhtC5mlTaCZiJ4AU3blyaqQLKLeJ
// SIG // a3pqyHBnJiXySNBrhLBkleguDLiqBLaziCWbQLAIlLUl
// SIG // ypI/cutECrDKU4/f7PHM+1gUQdK+WZnH/+t82oAY0VXG
// SIG // 3pUMZzv3UysNO4CS1aFAjQG5cjdJuS812n658mOSIPwF
// SIG // 5zmfaIH14qh/XPyfi0a6WdZaZIRth3dnP9VcGN1sDSuc
// SIG // RV/no9+aSPqWyt19ipN4jiuJILUHhm+3eekt2KGaKWys
// SIG // 2whswE1RkBoAq7GmvFIrXvcEB0mqM/09bIfgvkjN50z/
// SIG // 5XmMlyrqtmD0Fe+V1DTbfOyhdBZpt4G2cbqK3eoFUoJI
// SIG // ytn3N06zIBT0kd8BVWDWKOTi0VHsXx8cvHDKDLOL5iK2
// SIG // REcibwIDAQABo4IBfjCCAXowHwYDVR0lBBgwFgYKKwYB
// SIG // BAGCN0wIAQYIKwYBBQUHAwMwHQYDVR0OBBYEFMPGGeTy
// SIG // z3Y+F0AQcJOKcmziq1YbMFAGA1UdEQRJMEekRTBDMSkw
// SIG // JwYDVQQLEyBNaWNyb3NvZnQgT3BlcmF0aW9ucyBQdWVy
// SIG // dG8gUmljbzEWMBQGA1UEBRMNNDY0MjIzKzQ3MjIzNzAf
// SIG // BgNVHSMEGDAWgBRIbmTlUAXTgqoXNzcitW2oynUClTBU
// SIG // BgNVHR8ETTBLMEmgR6BFhkNodHRwOi8vd3d3Lm1pY3Jv
// SIG // c29mdC5jb20vcGtpb3BzL2NybC9NaWNDb2RTaWdQQ0Ey
// SIG // MDExXzIwMTEtMDctMDguY3JsMGEGCCsGAQUFBwEBBFUw
// SIG // UzBRBggrBgEFBQcwAoZFaHR0cDovL3d3dy5taWNyb3Nv
// SIG // ZnQuY29tL3BraW9wcy9jZXJ0cy9NaWNDb2RTaWdQQ0Ey
// SIG // MDExXzIwMTEtMDctMDguY3J0MAwGA1UdEwEB/wQCMAAw
// SIG // DQYJKoZIhvcNAQEMBQADggIBAGhKSnmsyGvycL6Dw4uq
// SIG // 3wDtwdM/hSbG6b5NqxUtIoE9TMT4Uqj+NWtYfrB09uq8
// SIG // OzxkLHnaEec19x5EyVxy+DBpbmzNU3/469qF4kyp0FNj
// SIG // CJlmFgFoxLNFzisxKeTXw1pFppM5AxHG+/VqIdQlOCbc
// SIG // 2nTSJLqxag4G3J+fsEE6uywxw6NxfieRBzAJd2HGPLUV
// SIG // pt87GLklNjsyxDUJYkxFtgkj1khGqwIG6ZNkbIXPsxR8
// SIG // S9oiKqAP71cZEwN6+TnnPIotqXeBsC+urL/NB8NWxBEe
// SIG // npVFFF4zNXd3sbmb4H/668DKQaIP5Qm0Ige2nmxgXAPq
// SIG // 9CPYZawXOvxOhOFgiU3AtLFAK/Oc+sgkXCeLX2A6RKq8
// SIG // SqgwHwtjWXaviyEToDFwSMdel+y+9wSZokXBwr+7TjGL
// SIG // uRinndUGjiVtJU/rsz/y9xC5TiOn6BAjwXB0EktoM0dP
// SIG // cTu3d9AC0q2gylEwTPAdfSbpABG+IPHEgtOoDxSBxUGc
// SIG // hdEElyklcwz6C8oGSXR6CVGHV7QW+cH03C9DH7nBBhAh
// SIG // UIojqCYwKb9b8Gam25brrUFwf8to5dXLZ14HYeRA9c6A
// SIG // H2CBwiE4ABPpOq/iypGWil8Vyg3Uf6LmgAEMMxZYLtNg
// SIG // 5GbM3tcTW2M3C0EZFIpiuT43hvm8uNHpXAZP3PJ3yCc5
// SIG // yR09MIIHejCCBWKgAwIBAgIKYQ6Q0gAAAAAAAzANBgkq
// SIG // hkiG9w0BAQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNV
// SIG // BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
// SIG // HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEy
// SIG // MDAGA1UEAxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNh
// SIG // dGUgQXV0aG9yaXR5IDIwMTEwHhcNMTEwNzA4MjA1OTA5
// SIG // WhcNMjYwNzA4MjEwOTA5WjB+MQswCQYDVQQGEwJVUzET
// SIG // MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
// SIG // bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
// SIG // aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWdu
// SIG // aW5nIFBDQSAyMDExMIICIjANBgkqhkiG9w0BAQEFAAOC
// SIG // Ag8AMIICCgKCAgEAq/D6chAcLq3YbqqCEE00uvK2WCGf
// SIG // Qhsqa+laUKq4BjgaBEm6f8MMHt03a8YS2AvwOMKZBrDI
// SIG // OdUBFDFC04kNeWSHfpRgJGyvnkmc6Whe0t+bU7IKLMOv
// SIG // 2akrrnoJr9eWWcpgGgXpZnboMlImEi/nqwhQz7NEt13Y
// SIG // xC4Ddato88tt8zpcoRb0RrrgOGSsbmQ1eKagYw8t00CT
// SIG // +OPeBw3VXHmlSSnnDb6gE3e+lD3v++MrWhAfTVYoonpy
// SIG // 4BI6t0le2O3tQ5GD2Xuye4Yb2T6xjF3oiU+EGvKhL1nk
// SIG // kDstrjNYxbc+/jLTswM9sbKvkjh+0p2ALPVOVpEhNSXD
// SIG // OW5kf1O6nA+tGSOEy/S6A4aN91/w0FK/jJSHvMAhdCVf
// SIG // GCi2zCcoOCWYOUo2z3yxkq4cI6epZuxhH2rhKEmdX4ji
// SIG // JV3TIUs+UsS1Vz8kA/DRelsv1SPjcF0PUUZ3s/gA4bys
// SIG // AoJf28AVs70b1FVL5zmhD+kjSbwYuER8ReTBw3J64HLn
// SIG // JN+/RpnF78IcV9uDjexNSTCnq47f7Fufr/zdsGbiwZeB
// SIG // e+3W7UvnSSmnEyimp31ngOaKYnhfsi+E11ecXL93KCjx
// SIG // 7W3DKI8sj0A3T8HhhUSJxAlMxdSlQy90lfdu+HggWCwT
// SIG // XWCVmj5PM4TasIgX3p5O9JawvEagbJjS4NaIjAsCAwEA
// SIG // AaOCAe0wggHpMBAGCSsGAQQBgjcVAQQDAgEAMB0GA1Ud
// SIG // DgQWBBRIbmTlUAXTgqoXNzcitW2oynUClTAZBgkrBgEE
// SIG // AYI3FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYw
// SIG // DwYDVR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBRyLToC
// SIG // MZBDuRQFTuHqp8cx0SOJNDBaBgNVHR8EUzBRME+gTaBL
// SIG // hklodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2Ny
// SIG // bC9wcm9kdWN0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFf
// SIG // MDNfMjIuY3JsMF4GCCsGAQUFBwEBBFIwUDBOBggrBgEF
// SIG // BQcwAoZCaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
// SIG // aS9jZXJ0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFfMDNf
// SIG // MjIuY3J0MIGfBgNVHSAEgZcwgZQwgZEGCSsGAQQBgjcu
// SIG // AzCBgzA/BggrBgEFBQcCARYzaHR0cDovL3d3dy5taWNy
// SIG // b3NvZnQuY29tL3BraW9wcy9kb2NzL3ByaW1hcnljcHMu
// SIG // aHRtMEAGCCsGAQUFBwICMDQeMiAdAEwAZQBnAGEAbABf
// SIG // AHAAbwBsAGkAYwB5AF8AcwB0AGEAdABlAG0AZQBuAHQA
// SIG // LiAdMA0GCSqGSIb3DQEBCwUAA4ICAQBn8oalmOBUeRou
// SIG // 09h0ZyKbC5YR4WOSmUKWfdJ5DJDBZV8uLD74w3LRbYP+
// SIG // vj/oCso7v0epo/Np22O/IjWll11lhJB9i0ZQVdgMknzS
// SIG // Gksc8zxCi1LQsP1r4z4HLimb5j0bpdS1HXeUOeLpZMlE
// SIG // PXh6I/MTfaaQdION9MsmAkYqwooQu6SpBQyb7Wj6aC6V
// SIG // oCo/KmtYSWMfCWluWpiW5IP0wI/zRive/DvQvTXvbiWu
// SIG // 5a8n7dDd8w6vmSiXmE0OPQvyCInWH8MyGOLwxS3OW560
// SIG // STkKxgrCxq2u5bLZ2xWIUUVYODJxJxp/sfQn+N4sOiBp
// SIG // mLJZiWhub6e3dMNABQamASooPoI/E01mC8CzTfXhj38c
// SIG // bxV9Rad25UAqZaPDXVJihsMdYzaXht/a8/jyFqGaJ+HN
// SIG // pZfQ7l1jQeNbB5yHPgZ3BtEGsXUfFL5hYbXw3MYbBL7f
// SIG // QccOKO7eZS/sl/ahXJbYANahRr1Z85elCUtIEJmAH9AA
// SIG // KcWxm6U/RXceNcbSoqKfenoi+kiVH6v7RyOA9Z74v2u3
// SIG // S5fi63V4GuzqN5l5GEv/1rMjaHXmr/r8i+sLgOppO6/8
// SIG // MO0ETI7f33VtY5E90Z1WTk+/gFcioXgRMiF670EKsT/7
// SIG // qMykXcGhiJtXcVZOSEXAQsmbdlsKgEhr/Xmfwb1tbWrJ
// SIG // UnMTDXpQzTGCGfUwghnxAgEBMIGVMH4xCzAJBgNVBAYT
// SIG // AlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQH
// SIG // EwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
// SIG // cG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2Rl
// SIG // IFNpZ25pbmcgUENBIDIwMTECEzMAAAMFTWINaIUHqjMA
// SIG // AAAAAwUwDQYJYIZIAWUDBAIBBQCgga4wGQYJKoZIhvcN
// SIG // AQkDMQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEO
// SIG // MAwGCisGAQQBgjcCARUwLwYJKoZIhvcNAQkEMSIEIKTQ
// SIG // ts56jQmXdTOrJhxHePDRP6IYHMqtdIFdJu6K2KWDMEIG
// SIG // CisGAQQBgjcCAQwxNDAyoBSAEgBNAGkAYwByAG8AcwBv
// SIG // AGYAdKEagBhodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20w
// SIG // DQYJKoZIhvcNAQEBBQAEggGAQQwHtLKIyVtgWoCqVsWv
// SIG // 4Bb/1jXrDx1cHMgtLhO2IfCl0IAt225VJnBz9khi4eks
// SIG // 4joPvjDAR3hxDVNE5r18kXquLb04I8x2MltCubELdP5h
// SIG // G6ChD3Zg9GNhhKeZXxb17ummzGwqAGspqvLBgJt0wfSK
// SIG // DZXhSZbohjel3cicJzpD0LrdH5D5I1IL10LEfVdKTNUL
// SIG // B9VKBAuX0bVgRWNJbIYV3XpKgPim8e+sBhPiWPBQrGah
// SIG // RTmhdcme8S69gx41RJZD8RbfxMiCCOuEHXqpeC4nprO2
// SIG // x9lNgdCdKvlWES5/NSNKmkCdZnLIUYLmaf1ThSSxUv12
// SIG // xqKxtdO7kYZ/ZgYb56+fAyboXdqEHBh+7z8SVtfP8xDh
// SIG // KtQB5QlT0Yig4/JqfEvQ7fs5PYs90PaqYpTGPR+iUwEd
// SIG // M2xnnpfLw9MERMA4Pk/GHSYGzHcBn2QNs3tbOtiTu9cS
// SIG // PJx4nVrPEP038J3UikE4U7WbegtWcva1nmoLSaWgKV2h
// SIG // bBA73iB4oYIW/zCCFvsGCisGAQQBgjcDAwExghbrMIIW
// SIG // 5wYJKoZIhvcNAQcCoIIW2DCCFtQCAQMxDzANBglghkgB
// SIG // ZQMEAgEFADCCAVAGCyqGSIb3DQEJEAEEoIIBPwSCATsw
// SIG // ggE3AgEBBgorBgEEAYRZCgMBMDEwDQYJYIZIAWUDBAIB
// SIG // BQAEIB+G11lKVwuucvxaFPbi9NMrkUnSKOjiMh1IwcjN
// SIG // 8A6xAgZjbRK5uG0YEjIwMjIxMjAyMTkyMjIxLjExWjAE
// SIG // gAIB9KCB0KSBzTCByjELMAkGA1UEBhMCVVMxEzARBgNV
// SIG // BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
// SIG // HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEl
// SIG // MCMGA1UECxMcTWljcm9zb2Z0IEFtZXJpY2EgT3BlcmF0
// SIG // aW9uczEmMCQGA1UECxMdVGhhbGVzIFRTUyBFU046MTJC
// SIG // Qy1FM0FFLTc0RUIxJTAjBgNVBAMTHE1pY3Jvc29mdCBU
// SIG // aW1lLVN0YW1wIFNlcnZpY2WgghFXMIIHDDCCBPSgAwIB
// SIG // AgITMwAAAcpPwrPtAw0YbAABAAAByjANBgkqhkiG9w0B
// SIG // AQsFADB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2Fz
// SIG // aGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UE
// SIG // ChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQD
// SIG // Ex1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDAe
// SIG // Fw0yMjExMDQxOTAxNDBaFw0yNDAyMDIxOTAxNDBaMIHK
// SIG // MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3Rv
// SIG // bjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWlj
// SIG // cm9zb2Z0IENvcnBvcmF0aW9uMSUwIwYDVQQLExxNaWNy
// SIG // b3NvZnQgQW1lcmljYSBPcGVyYXRpb25zMSYwJAYDVQQL
// SIG // Ex1UaGFsZXMgVFNTIEVTTjoxMkJDLUUzQUUtNzRFQjEl
// SIG // MCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUtU3RhbXAgU2Vy
// SIG // dmljZTCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoC
// SIG // ggIBAMMBnKvY+dK1hJHC0pRmS8HlFX8V0WlI4j7MmjVc
// SIG // T3TEbNwlXufLIrvxJGlbe7ezzUz5KP7PJTbbrAHixJ85
// SIG // IuOMsZNnPXpJvBNUkNmFfW/PyzsXymqWfLVZT8scOg5h
// SIG // czRUI4n1ZvBIme5RUaGOOPL6XGwQ9fKo2DRf9md0kHIX
// SIG // LHVdTfWOldlhpeeVZi6hUV+fnabXY63gV84t1lvU7KAh
// SIG // FnGAgSucGIEvbU9kkkk82nt45ncONIPiziMq1Txdg6M5
// SIG // Erb+iQQz78GoV1qShqTu6x6yhfqOxAjf1YkBTGcqf78X
// SIG // j4lAAQzasxFCPLO5JWJnh1743kDqvwjNwv2PG493yTm5
// SIG // 2R+3gF70Q58U/Eelv7g9ZhlCb7/TPQTLt54SqSpksc8z
// SIG // uS7XDBIdrTF8YTBhjTFD9wzhCt1/tvyw9WdN7rCU5OaR
// SIG // zaB/4AyL26e/OwsONLbAKYgL7ax2MLm9E6iL/GcutpfJ
// SIG // /LPzL/z++uAk6q8XF82pQR4fl8uFz45mnZz5GScnKdyn
// SIG // M25IPUG7yadB/9BbMB0vnnxaH6QzScC4dYbP2jItSv6M
// SIG // xL+/1iyD7A4Cten1P2scm6jCpNDTsYHpVIwGCpeMFNGO
// SIG // kOKvTf/T8AEtHLIn0IWNaKEHwCNIgwgkhAE7JQ/G0ztL
// SIG // UbanXCHWrzkXqs6D3bwL9w69V10PAgMBAAGjggE2MIIB
// SIG // MjAdBgNVHQ4EFgQU+sf+pUuBEkPCmYXdEYFO0WFzPH8w
// SIG // HwYDVR0jBBgwFoAUn6cVXQBeYl2D9OXSZacbUzUZ6XIw
// SIG // XwYDVR0fBFgwVjBUoFKgUIZOaHR0cDovL3d3dy5taWNy
// SIG // b3NvZnQuY29tL3BraW9wcy9jcmwvTWljcm9zb2Z0JTIw
// SIG // VGltZS1TdGFtcCUyMFBDQSUyMDIwMTAoMSkuY3JsMGwG
// SIG // CCsGAQUFBwEBBGAwXjBcBggrBgEFBQcwAoZQaHR0cDov
// SIG // L3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jZXJ0cy9N
// SIG // aWNyb3NvZnQlMjBUaW1lLVN0YW1wJTIwUENBJTIwMjAx
// SIG // MCgxKS5jcnQwDAYDVR0TAQH/BAIwADATBgNVHSUEDDAK
// SIG // BggrBgEFBQcDCDANBgkqhkiG9w0BAQsFAAOCAgEA2NB5
// SIG // KgktyrinnxV/P65v3bQ/dOunShJXjaq4sGarDOGJvBMO
// SIG // EIqjqju5lqGGGOCucvHl0jhyjVzn6TukW2mI/IwjnCQA
// SIG // ebai5eYYjIGjGwFS65dYZYsfbJaDuOSzjdCaYSr2tw+g
// SIG // FSgOz+/JgPYkR2WFFa0Ysn70I1sZlJ8YYrPH6Jvdvv0R
// SIG // 3BGdQ4efqeIM3ni/OGJdNFsqvRHIASin4KtJQo1jUqtQ
// SIG // FBtbBC5YFzkrymeP5V1x/jH4XB3vdViyGmZEvx7vcHU0
// SIG // +iNeAQve8oQ7GVlwJdCCfNNSOlLRBaQrE3jsmQSewhdK
// SIG // 3+ZcSfLRPaIzbMqlySrsFZ9HsAjJGas/3BML/RRMfEJr
// SIG // GdGTaHU7bJflfXWZvnlKzCmZOjyrCgK7UPox5H1bB4Cj
// SIG // g5aHpaTph6oF+1GztDVZyJaT+eYEE6le+r1O8EV6VH8+
// SIG // yoRNwWVzYMBtOXUZwlw8K4YWM/iLW87NStUfCOGDAyY1
// SIG // vdAEgoPSX/scoESmRih46NgbNl8mirjdT+hRQiFVzeyo
// SIG // B5f22YmpBqu5OU0ODlyucZIQh4Y3YB7sY94SuQGjsvhl
// SIG // 8Tv428qhkanksX/k0z7loQ1rqyKN90TAxnuQ2yJo3G3I
// SIG // +nVYUHr6hwpUdTh0n6/vJtYVkSRpQtWrXDlimowK8DlE
// SIG // aiUlZU4cFYCMsxjZo84wggdxMIIFWaADAgECAhMzAAAA
// SIG // FcXna54Cm0mZAAAAAAAVMA0GCSqGSIb3DQEBCwUAMIGI
// SIG // MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3Rv
// SIG // bjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWlj
// SIG // cm9zb2Z0IENvcnBvcmF0aW9uMTIwMAYDVQQDEylNaWNy
// SIG // b3NvZnQgUm9vdCBDZXJ0aWZpY2F0ZSBBdXRob3JpdHkg
// SIG // MjAxMDAeFw0yMTA5MzAxODIyMjVaFw0zMDA5MzAxODMy
// SIG // MjVaMHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNo
// SIG // aW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQK
// SIG // ExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMT
// SIG // HU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEwMIIC
// SIG // IjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEA5OGm
// SIG // TOe0ciELeaLL1yR5vQ7VgtP97pwHB9KpbE51yMo1V/YB
// SIG // f2xK4OK9uT4XYDP/XE/HZveVU3Fa4n5KWv64NmeFRiMM
// SIG // tY0Tz3cywBAY6GB9alKDRLemjkZrBxTzxXb1hlDcwUTI
// SIG // cVxRMTegCjhuje3XD9gmU3w5YQJ6xKr9cmmvHaus9ja+
// SIG // NSZk2pg7uhp7M62AW36MEBydUv626GIl3GoPz130/o5T
// SIG // z9bshVZN7928jaTjkY+yOSxRnOlwaQ3KNi1wjjHINSi9
// SIG // 47SHJMPgyY9+tVSP3PoFVZhtaDuaRr3tpK56KTesy+uD
// SIG // RedGbsoy1cCGMFxPLOJiss254o2I5JasAUq7vnGpF1tn
// SIG // YN74kpEeHT39IM9zfUGaRnXNxF803RKJ1v2lIH1+/Nme
// SIG // Rd+2ci/bfV+AutuqfjbsNkz2K26oElHovwUDo9Fzpk03
// SIG // dJQcNIIP8BDyt0cY7afomXw/TNuvXsLz1dhzPUNOwTM5
// SIG // TI4CvEJoLhDqhFFG4tG9ahhaYQFzymeiXtcodgLiMxhy
// SIG // 16cg8ML6EgrXY28MyTZki1ugpoMhXV8wdJGUlNi5UPkL
// SIG // iWHzNgY1GIRH29wb0f2y1BzFa/ZcUlFdEtsluq9QBXps
// SIG // xREdcu+N+VLEhReTwDwV2xo3xwgVGD94q0W29R6HXtqP
// SIG // nhZyacaue7e3PmriLq0CAwEAAaOCAd0wggHZMBIGCSsG
// SIG // AQQBgjcVAQQFAgMBAAEwIwYJKwYBBAGCNxUCBBYEFCqn
// SIG // Uv5kxJq+gpE8RjUpzxD/LwTuMB0GA1UdDgQWBBSfpxVd
// SIG // AF5iXYP05dJlpxtTNRnpcjBcBgNVHSAEVTBTMFEGDCsG
// SIG // AQQBgjdMg30BATBBMD8GCCsGAQUFBwIBFjNodHRwOi8v
// SIG // d3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL0RvY3MvUmVw
// SIG // b3NpdG9yeS5odG0wEwYDVR0lBAwwCgYIKwYBBQUHAwgw
// SIG // GQYJKwYBBAGCNxQCBAweCgBTAHUAYgBDAEEwCwYDVR0P
// SIG // BAQDAgGGMA8GA1UdEwEB/wQFMAMBAf8wHwYDVR0jBBgw
// SIG // FoAU1fZWy4/oolxiaNE9lJBb186aGMQwVgYDVR0fBE8w
// SIG // TTBLoEmgR4ZFaHR0cDovL2NybC5taWNyb3NvZnQuY29t
// SIG // L3BraS9jcmwvcHJvZHVjdHMvTWljUm9vQ2VyQXV0XzIw
// SIG // MTAtMDYtMjMuY3JsMFoGCCsGAQUFBwEBBE4wTDBKBggr
// SIG // BgEFBQcwAoY+aHR0cDovL3d3dy5taWNyb3NvZnQuY29t
// SIG // L3BraS9jZXJ0cy9NaWNSb29DZXJBdXRfMjAxMC0wNi0y
// SIG // My5jcnQwDQYJKoZIhvcNAQELBQADggIBAJ1VffwqreEs
// SIG // H2cBMSRb4Z5yS/ypb+pcFLY+TkdkeLEGk5c9MTO1OdfC
// SIG // cTY/2mRsfNB1OW27DzHkwo/7bNGhlBgi7ulmZzpTTd2Y
// SIG // urYeeNg2LpypglYAA7AFvonoaeC6Ce5732pvvinLbtg/
// SIG // SHUB2RjebYIM9W0jVOR4U3UkV7ndn/OOPcbzaN9l9qRW
// SIG // qveVtihVJ9AkvUCgvxm2EhIRXT0n4ECWOKz3+SmJw7wX
// SIG // sFSFQrP8DJ6LGYnn8AtqgcKBGUIZUnWKNsIdw2FzLixr
// SIG // e24/LAl4FOmRsqlb30mjdAy87JGA0j3mSj5mO0+7hvoy
// SIG // GtmW9I/2kQH2zsZ0/fZMcm8Qq3UwxTSwethQ/gpY3UA8
// SIG // x1RtnWN0SCyxTkctwRQEcb9k+SS+c23Kjgm9swFXSVRk
// SIG // 2XPXfx5bRAGOWhmRaw2fpCjcZxkoJLo4S5pu+yFUa2pF
// SIG // EUep8beuyOiJXk+d0tBMdrVXVAmxaQFEfnyhYWxz/gq7
// SIG // 7EFmPWn9y8FBSX5+k77L+DvktxW/tM4+pTFRhLy/AsGC
// SIG // onsXHRWJjXD+57XQKBqJC4822rpM+Zv/Cuk0+CQ1Zyvg
// SIG // DbjmjJnW4SLq8CdCPSWU5nR0W2rRnj7tfqAxM328y+l7
// SIG // vzhwRNGQ8cirOoo6CGJ/2XBjU02N7oJtpQUQwXEGahC0
// SIG // HVUzWLOhcGbyoYICzjCCAjcCAQEwgfihgdCkgc0wgcox
// SIG // CzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9u
// SIG // MRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
// SIG // b3NvZnQgQ29ycG9yYXRpb24xJTAjBgNVBAsTHE1pY3Jv
// SIG // c29mdCBBbWVyaWNhIE9wZXJhdGlvbnMxJjAkBgNVBAsT
// SIG // HVRoYWxlcyBUU1MgRVNOOjEyQkMtRTNBRS03NEVCMSUw
// SIG // IwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2
// SIG // aWNloiMKAQEwBwYFKw4DAhoDFQCjjueXDE+LMjz+pwpY
// SIG // NiFn2ozKpKCBgzCBgKR+MHwxCzAJBgNVBAYTAlVTMRMw
// SIG // EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
// SIG // b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
// SIG // b24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1w
// SIG // IFBDQSAyMDEwMA0GCSqGSIb3DQEBBQUAAgUA5zSRhTAi
// SIG // GA8yMDIyMTIwMjIzMDAyMVoYDzIwMjIxMjAzMjMwMDIx
// SIG // WjB3MD0GCisGAQQBhFkKBAExLzAtMAoCBQDnNJGFAgEA
// SIG // MAoCAQACAiQ4AgH/MAcCAQACAhHwMAoCBQDnNeMFAgEA
// SIG // MDYGCisGAQQBhFkKBAIxKDAmMAwGCisGAQQBhFkKAwKg
// SIG // CjAIAgEAAgMHoSChCjAIAgEAAgMBhqAwDQYJKoZIhvcN
// SIG // AQEFBQADgYEAHeIEox+YNYggCoRlD2CGZ/QJ6yUPxaQA
// SIG // FWpeMswUSJ7qOT/UgB4gSaQxdNHcLkO3W6tf3x2zPI/d
// SIG // +dhTWDsAOCw6ibXaO+/YNhrJ4IrPZ5tiTHMxIZWrvhTa
// SIG // aTKU3wFC1Emo23np6BlftVS2up7iGFFfe/E/SOFGueB4
// SIG // IY3nfDgxggQNMIIECQIBATCBkzB8MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1T
// SIG // dGFtcCBQQ0EgMjAxMAITMwAAAcpPwrPtAw0YbAABAAAB
// SIG // yjANBglghkgBZQMEAgEFAKCCAUowGgYJKoZIhvcNAQkD
// SIG // MQ0GCyqGSIb3DQEJEAEEMC8GCSqGSIb3DQEJBDEiBCBx
// SIG // 9qn62cBETUfzieXwiRYPjrAV4QRNo+D2w4cHYDlGjjCB
// SIG // +gYLKoZIhvcNAQkQAi8xgeowgecwgeQwgb0EIBM9G/Ob
// SIG // 61VNrJWQJOI7dUgxJOiM2QMFQqFsBdys3BrgMIGYMIGA
// SIG // pH4wfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
// SIG // bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoT
// SIG // FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMd
// SIG // TWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTACEzMA
// SIG // AAHKT8Kz7QMNGGwAAQAAAcowIgQgWbpiNMRiPVTVaDKn
// SIG // 4iBdjrlaIfuEvcECxdYqXdxzt5QwDQYJKoZIhvcNAQEL
// SIG // BQAEggIANpGTQHSa/sKEHEl+UYm9LGK9IQI6ygveXk2y
// SIG // 5o50aj9BCbj31692vGkMsxnqzRZGKy++2bTigJpXxDBR
// SIG // e9syHuPFXfSmNrEUJoq9GE48VOodzUUf+zs+4PEHtWu1
// SIG // 9KsfsjnFCGCAiB+koQfMeR1nNu0A1TWgTn975eZVcgFc
// SIG // ZVHmgqMOaN5rLCGcCvrBmo2J8xiTphGa4m/qk3iedHRu
// SIG // yt1sgVf3ixqo5bflkg3o5fXQvVoVOS9xxcBIGbnJOZf3
// SIG // QVKmbRaYOn5B5Vx+raNItC9THZaPtqHlmx+sdVfn4wm3
// SIG // 3LerLqeGlAYW8R2X/2sEndLK66uXZJVcZfzICW0XxNTr
// SIG // w8WmrRpQA9fDEAdzaGzlQEsBm3GDa3XTQpwbq4QAw6XA
// SIG // aA0tbxjo6yikVODPNagEr1mEci/sHT2EsNT3g9bAjiGy
// SIG // /28gS+oPXZ9qnYs+RnZbHAu4kSBTdHXOI/Cu+3xABj2i
// SIG // 3NOj2GsortL+e62wwoAmTtVf3VIqshjPfczhOPvQVPTI
// SIG // tmmT0gSLCVLUkWbm5IheQBJUaoJzt7JfkEZ2IYYG62LO
// SIG // Tw3cc2YqlXVknbOoj2UlRqF0mjiOQtT8l5ZdPdE9KgXg
// SIG // vFAFm+qXbIvJ+du4BPJ99tttAA65I1ltHhSA3LHMJMXO
// SIG // gkbXO2iuQNG1YWjHci5wgLPw4raP+Kg=
// SIG // End signature block
